import { RecoilRoot } from 'recoil';
import PropTypes from 'prop-types';
import AtomsHydrator from './AtomsHydrator';

/**
 * A [Recoil data store provider][recoil-root] that can be used to manage
 * global state for your application. By default it initializes the
 * `breakpoint` atoms.
 *
 * ```js
 *
 * import { AtomsRoot } from '@politico/interactive-style';
 * ```
 *
 * [recoil-root]: https://recoiljs.org/docs/api-reference/core/RecoilRoot
 */
const AtomsRoot = function AtomsRoot(props) {
  const {
    initializeState,
    children
  } = props;
  return <RecoilRoot initializeState={initializeState}>
      <AtomsHydrator />
      {children}
    </RecoilRoot>;
};
AtomsRoot.defaultProps = {
  initializeState: undefined
};
AtomsRoot.propTypes = {
  /**
   * Initialization function to initialize the Recoil state via
   * a `MutableSnapshot`. See [the Recoil documentation][docs] for more
   * information.
   *
   * [docs]: https://recoiljs.org/docs/api-reference/core/Snapshot/#state-initialization
   */
  initializeState: PropTypes.func,
  /**
   * The children to render inside this Recoil root, for which the provided
   * data store will be available.
   */
  children: PropTypes.oneOfType([PropTypes.node, PropTypes.arrayOf(PropTypes.node)]).isRequired
};
export default AtomsRoot;