import classnames from 'classnames';
import customizable from "../../../../utils/css/customizable.js";
import useMarkdownContext from '../context';
const tagNameMap = {
  h1: 'heading-one',
  h2: 'heading-two',
  h3: 'heading-three',
  h4: 'heading-four',
  h5: 'heading-five',
  h6: 'heading-six',
  p: 'paragraph',
  blockquote: 'blockquote',
  ol: 'numbered-list',
  ul: 'bulleted-list',
  li: 'list-item',
  hr: 'rule',
  img: 'image',
  a: 'link',
  strong: 'strong',
  em: 'emphasis',
  code: 'code'
};
const Node = function Node(props) {
  const {
    children,
    node
  } = props;
  const {
    components: customComponents = {},
    classes
  } = useMarkdownContext();
  const {
    tagName
  } = node;
  const nodeName = tagNameMap[tagName];
  const Tag = customComponents[nodeName] || tagName;
  const isCustomComponent = !!customComponents[nodeName];
  return <Tag className={classnames(customizable(`MarkdownContent__${nodeName}`), classes[nodeName])} node={isCustomComponent ? node : undefined} {...node.properties}>
      {children}
    </Tag>;
};
export default Node;